@@ -19,14 +19,14 @@ async def _(matcher: Matcher, bot: Bot, event: Event):
     plugin = matcher.plugin_name
 
     conv = {
-        "user": [event.user_id] if hasattr(event, "user_id") else [],
-        "group": [event.group_id] if hasattr(event, "group_id") else [],
+        "user": [event.user_id] if hasattr(event, "user_id") else [],  # type: ignore
+        "group": [event.group_id] if hasattr(event, "group_id") else [],  # type: ignore
     }
 
     if (
         hasattr(event, "user_id")
         and not hasattr(event, "group_id")
-        and str(event.user_id) in bot.config.superusers
+        and str(event.user_id) in bot.config.superusers  # type: ignore
     ):
         conv["user"] = []
         conv["group"] = []
@@ -38,7 +38,7 @@ async def _(matcher: Matcher, bot: Bot, event: Event):
         }
     )
 
-    if not plugin_manager.get_plugin(conv=conv, perm=1)[plugin]:
+    if plugin and not plugin_manager.get_plugin(conv=conv, perm=1)[plugin]:
         raise IgnoredException(f"Nonebot Plugin Manager has blocked {plugin} !")
 
 
@@ -57,5 +57,11 @@ async def _(bot: Bot, event: MessageEvent, args: Namespace = ShellCommandArgs())
 
     if hasattr(args, "handle"):
         message = getattr(Handle, args.handle)(args)
-        if message:
-            await bot.send(event, message)
+        if message is not None:
+            message = message.split("\n")
+            i = 1
+            while len(message) > 30:
+                await bot.send(event, "\n".join(message[:30]) + f"\n【第{i}页】")
+                message = message[31:]
+                i = i + 1
+            await bot.send(event, "\n".join(message[:30]) + "\n【完】")
